pub struct WebViewerData { /* private fields */ }Expand description
The contents of the files that make up the web viewer application.
Loaded once per WebViewerServer, via WebViewerData::load for the built-in assets
(which does not exist in disable_web_viewer_server builds) or via WebViewerData::from_dir
/ WebViewerData::from_archive for assets on disk.
Implementations
Sourceimpl WebViewerData
impl WebViewerData
Sourcepub fn from_archive(path: &Path) -> Result<Self, WebViewerDataError>
pub fn from_archive(path: &Path) -> Result<Self, WebViewerDataError>
Load the web viewer assets from a zip archive on disk.
The archive must contain the files produced by the web viewer build
(pixi run rerun-build-web) at the archive root.
Sourcepub fn from_dir(dir: &Path) -> Result<Self, WebViewerDataError>
pub fn from_dir(dir: &Path) -> Result<Self, WebViewerDataError>
Load the web viewer assets from a directory on disk.
The directory must contain the files produced by the web viewer build
(pixi run rerun-build-web), i.e. <workspace>/crates/viewer/re_web_viewer_server/web_viewer.
Sourceimpl WebViewerData
impl WebViewerData
pub fn index_html(&self) -> &[u8] ⓘ
pub fn favicon(&self) -> &[u8] ⓘ
pub fn apple_touch_icon(&self) -> &[u8] ⓘ
pub fn sw_js(&self) -> &[u8] ⓘ
pub fn viewer_js(&self) -> &[u8] ⓘ
pub fn viewer_wasm(&self) -> &[u8] ⓘ
pub fn signed_in_html(&self) -> &[u8] ⓘ
pub fn signed_out_html(&self) -> &[u8] ⓘ