pub struct WebViewerServerHandle { /* private fields */ }Expand description
Sync handle for the WebViewerServer
When dropped, the server will be shut down.
Implementations
sourceimpl WebViewerServerHandle
impl WebViewerServerHandle
sourcepub fn new(
bind_ip: &str,
requested_port: WebViewerServerPort
) -> Result<Self, WebViewerServerError>
pub fn new( bind_ip: &str, requested_port: WebViewerServerPort ) -> Result<Self, WebViewerServerError>
Create new WebViewerServer to host the Rerun Web Viewer on a specified port.
Returns a WebViewerServerHandle that will shutdown the server when dropped.
A port of 0 will let the OS choose a free port.
The caller needs to ensure that there is a tokio runtime running.
sourcepub fn server_url(&self) -> String
pub fn server_url(&self) -> String
Includes http:// prefix